@@ -5,16 +5,6 @@
 #'
 #' @param obs_url character containing the url for the retrieval
 #' @param \dots information to pass to header request
-#' @importFrom httr GET
-#' @importFrom httr POST
-#' @importFrom httr RETRY
-#' @importFrom httr user_agent
-#' @importFrom httr stop_for_status
-#' @importFrom httr status_code
-#' @importFrom httr headers
-#' @importFrom httr content
-#' @importFrom httr content_type
-#' @importFrom curl curl_version
 #' @importFrom xml2 xml_text
 #' @importFrom xml2 xml_child
 #' @importFrom xml2 read_xml
@@ -34,20 +24,20 @@ getWebServiceData <- function(obs_url, ...){
   
   returnedList <- retryGetOrPost(obs_url, ...)
   
-  if(status_code(returnedList) == 400){
-    response400 <- content(returnedList, type="text", encoding = "UTF-8")
+  if(httr::status_code(returnedList) == 400){
+    response400 <- httr::content(returnedList, type="text", encoding = "UTF-8")
     statusReport <- xml_text(xml_child(read_xml(response400), 2)) # making assumption that - body is second node
     statusMsg <- gsub(pattern=", server=.*", replacement="", x = statusReport)
     stop(statusMsg)
-  } else if(status_code(returnedList) != 200){
+  } else if(httr::status_code(returnedList) != 200){
     message("For: ", obs_url,"\n")
-    stop_for_status(returnedList)
+    httr::stop_for_status(returnedList)
   } else {
     
-    headerInfo <- headers(returnedList)
+    headerInfo <- httr::headers(returnedList)
 
     if(headerInfo$`content-type` %in% c("text/tab-separated-values;charset=UTF-8")){
-      returnedDoc <- content(returnedList, type="text",encoding = "UTF-8")
+      returnedDoc <- httr::content(returnedList, type="text",encoding = "UTF-8")
     } else if (headerInfo$`content-type` %in% 
                c("application/zip", 
                  "application/zip;charset=UTF-8",
@@ -61,7 +51,7 @@ getWebServiceData <- function(obs_url, ...){
       
 
     } else {
-      returnedDoc <- content(returnedList,encoding = "UTF-8")
+      returnedDoc <- httr::content(returnedList,encoding = "UTF-8")
       if(grepl("No sites/data found using the selection criteria specified", returnedDoc)){
         message(returnedDoc)
       }
@@ -86,7 +76,7 @@ getWebServiceData <- function(obs_url, ...){
 
 default_ua <- function() {
   versions <- c(
-    libcurl = curl_version()$version,
+    libcurl = curl::curl_version()$version,
     httr = as.character(packageVersion("httr")),
     dataRetrieval = as.character(packageVersion("dataRetrieval"))
   )
@@ -96,11 +86,9 @@ default_ua <- function() {
 #' getting header information from a WQP query
 #'
 #'@param url the query url
-#'@importFrom httr HEAD
-#'@importFrom httr headers
 getQuerySummary <- function(url){
-  queryHEAD <- HEAD(url)
-  retquery <- headers(queryHEAD)
+  queryHEAD <- httr::HEAD(url)
+  retquery <- httr::headers(queryHEAD)
   
   retquery[grep("-count",names(retquery))] <- as.numeric(retquery[grep("-count",names(retquery))])
   
@@ -114,13 +102,13 @@ getQuerySummary <- function(url){
 retryGetOrPost <- function(obs_url, ...) {
   resp <- NULL
   if (nchar(obs_url) < 2048 || grepl(pattern = "ngwmn", x = obs_url)) {
-    resp <- RETRY("GET", obs_url, ..., user_agent(default_ua()))
+    resp <- httr::RETRY("GET", obs_url, ..., httr::user_agent(default_ua()))
   } else {
     split <- strsplit(obs_url, "?", fixed=TRUE)
     obs_url <- split[[1]][1]
     query <- split[[1]][2]
-    resp <- RETRY("POST", obs_url, ..., body = query,
-          content_type("application/x-www-form-urlencoded"), user_agent(default_ua()))
+    resp <- httr::RETRY("POST", obs_url, ..., body = query,
+                        httr::content_type("application/x-www-form-urlencoded"), httr::user_agent(default_ua()))
   }
   return(resp)
 }
\ No newline at end of file
