@@ -1,10 +1,9 @@
 #' Site Data Import from Water Quality Portal
 #'
-#' Returns a list of sites from the Water Quality Portal web service. This function gets the data from: \url{http://www.waterqualitydata.us}.
-#' Arguments to the function should be based on \url{www.waterqualitydata.us/webservices_documentation.jsp}
+#' Returns a list of sites from the Water Quality Portal web service. This function gets the data from: \url{https://www.waterqualitydata.us}.
+#' Arguments to the function should be based on \url{https://www.waterqualitydata.us/webservices_documentation}
 #'
-#' @param \dots see \url{www.waterqualitydata.us/webservices_documentation.jsp} for a complete list of options
-#' @param zip logical to request data via downloading zip file. Default set to FALSE.
+#' @param \dots see \url{https://www.waterqualitydata.us/webservices_documentation} for a complete list of options. A list of arguments can also be supplied.
 #' @keywords data import WQP web service
 #' @return A data frame with at least the following columns:
 #' \tabular{lll}{ 
@@ -58,51 +57,25 @@
 #' sites <- whatWQPsites(countycode="US:55:025",siteType=type)
 #' lakeSites <- whatWQPsites(siteType = "Lake, Reservoir, Impoundment", statecode = "US:55")
 #' }
-whatWQPsites <- function(...,zip=FALSE){
+whatWQPsites <- function(...){
 
-  matchReturn <- list(...)
-  
-  values <- sapply(matchReturn, function(x) as.character(paste(eval(x),collapse=";",sep="")))
+  values <- readWQPdots(...)
   
   if("tz" %in% names(values)){
     values <- values[!(names(values) %in% "tz")]
   }
   
-  if("statecode" %in% names(values)){
-    stCd <- values["statecode"]
-    if(!grepl("US:",stCd)){
-      values["statecode"] <- paste0("US:",stateCdLookup(stCd, "id"))
-    }
-  }
-  
-  if("stateCd" %in% names(values)){
-    stCd <- values["stateCd"]
-    if(!grepl("US:",stCd)){
-      values["stateCd"] <- paste0("US:",stateCdLookup(stCd, "id"))
-    }
-    names(values)[names(values) == "stateCd"] <- "statecode"
-  }
-  
-  if("bBox" %in% names(values)){
-    values['bBox'] <- gsub(pattern = ";", replacement = ",", x = values['bBox'])
-  }
-  
-  values <- checkWQPdates(values)
-  
   values <- sapply(values, function(x) URLencode(x, reserved = TRUE))
     
   urlCall <- paste(paste(names(values),values,sep="="),collapse="&")
   
   
-  baseURL <- "http://www.waterqualitydata.us/Station/search?"
+  baseURL <- drURL("wqpStation")
   urlCall <- paste0(baseURL,
                urlCall,
                "&mimeType=tsv&sorted=no")
-  if(zip){
-    urlCall <- paste0(urlCall,"&zip=yes")
-  }
-  
-  retval <- importWQP(urlCall, zip=zip)
+
+  retval <- importWQP(urlCall, zip=values["zip"] == "yes")
   
   attr(retval, "queryTime") <- Sys.time()
   attr(retval, "url") <- urlCall
